pub struct Attrs<'a> {
pub font_size: f32,
/* private fields */
}Expand description
Text attributes
Fields
font_size: f32Implementations
Sourceimpl<'a> Attrs<'a>
impl<'a> Attrs<'a>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new set of attributes with sane defaults
This defaults to a regular Sans-Serif font.
Sourcepub fn family(self, family: &'a [FamilyOwned]) -> Self
pub fn family(self, family: &'a [FamilyOwned]) -> Self
Set Family
Sourcepub fn raw_weight(self, weight: u16) -> Self
pub fn raw_weight(self, weight: u16) -> Self
Set Weight from u16 value
Sourcepub fn line_height(self, line_height: LineHeightValue) -> Self
pub fn line_height(self, line_height: LineHeightValue) -> Self
Set line height
Sourcepub fn compatible(&self, other: &Self) -> bool
pub fn compatible(&self, other: &Self) -> bool
Check if this set of attributes can be shaped with another